@@ -165,16 +165,16 @@ class Downloader:
     def report(self):
         items: list[tuple[str, int]] = [
             ("Added users", len(set(self.added_users))),
-            ("Added submissions", len(set(self.added_submissions))),
-            ("Added journals", len(set(self.added_journals))),
             ("Modified users", len(self.modified_users)),
-            ("Modified submissions", len(self.modified_submissions)),
-            ("Modified journals", len(self.modified_journals)),
             ("Users deactivated", len(self.user_deactivated)),
             ("User errors", len(self.user_errors)),
+            ("Added submissions", len(set(self.added_submissions))),
+            ("Modified submissions", len(self.modified_submissions)),
             ("Submission errors", len(self.submission_errors)),
             ("File errors", len(self.file_errors)),
             ("Thumbnail errors", len(self.thumbnail_errors)),
+            ("Added journals", len(set(self.added_journals))),
+            ("Modified journals", len(self.modified_journals)),
             ("Journal Errors", len(self.journal_errors)),
         ]
         if items := list(filter(itemgetter(1), items)):
@@ -374,7 +374,7 @@ class Downloader:
                         JournalsColumns.USERUPDATE.value.name: 1,
                     })
                     self.db.commit()
-                    self.bar_message("#" * self.bar_width, green)
+                    self.bar_message("ADDED", green)
                     self.bar_close()
                     self.added_journals += [journal.id]
                 if stop == 0:
@@ -421,7 +421,8 @@ class Downloader:
                             self.clear_line()
                         else:
                             self.bar_close()
-                    elif folder != Folder.favorites and self.db.submissions.set_user_update(sub_partial.id, 1):
+                    elif folder != Folder.favorites and (self.db.submissions.set_user_update(sub_partial.id, 1) or
+                                                         self.db.submissions.set_folder(sub_partial.id, folder.value)):
                         self.db.commit()
                         self.bar_message("UPDATED", green, always=True)
                         self.modified_submissions += [sub_partial.id]
@@ -461,7 +462,7 @@ class Downloader:
         user, err = download_catch(self.api.user, username)
         self.err_to_bar(err)
         if err:
-            self.user_errors += [user]
+            self.user_errors += [username]
             return err
         added: bool = (current := self.db.users[username][UsersColumns.USERPAGE.value.name]) == ""
         updated: bool = not added and user.profile != current
@@ -471,8 +472,8 @@ class Downloader:
             self.clear_line()
             return 0
         self.db.users[username] = self.db.users[username] | {UsersColumns.USERPAGE.value.name: user.profile}
-        self.added_users += [user] if added else []
-        self.modified_users += [user] if updated else []
+        self.added_users += [username] if added else []
+        self.modified_users += [username] if updated else []
         self.bar_message("ADDED" if added else "UPDATED", green, always=True)
         return 0
 
@@ -516,6 +517,13 @@ class Downloader:
         self._download_users([(u, folders) for u in users])
 
     def download_users_update(self, users: list[str], folders: list[str], stop: int, deactivated: bool):
+        for user in [u for u in users if u not in self.db.users]:
+            padding: int = terminal_width() - 1 - self.bar_width - 2
+            echo(f"{green}{user:<{padding}}{reset}", nl=self.output == OutputType.simple, color=self.color)
+            self.bar()
+            self.bar_message("NOT IN DB", red, always=True)
+            self.bar_close()
+
         users_cursor: Iterable[dict] = self.db.users[users] if users else self.db.users.select(
             order=[UsersColumns.USERNAME.value.name])
         users_folders: Iterable[tuple[str, list[str]]]
@@ -586,5 +594,5 @@ class Downloader:
             }, replace=replace)
             self.added_journals += [journal.id]
             self.db.commit()
-            self.bar_message("#" * self.bar_width, green, always=True)
+            self.bar_message("ADDED", green, always=True)
             self.bar_close()
